@@ -1,5 +1,5 @@
-#!/bin/bash
-# lesspipe.sh, a preprocessor for less (version 2.05)
+#!/usr/bin/env bash
+# lesspipe.sh, a preprocessor for less (version 2.06)
 # Author: Wolfgang Friebel (wp.friebel AT gmail.com)
 #( [[ -n 1 && -n 2 ]] ) > /dev/null 2>&1 || exec zsh -y --ksh-arrays -- "$0" ${1+"$@"}
 
@@ -20,14 +20,16 @@ filetype () {
 	# do not depend on the file extension, if possible
 	fname="$1"
 	if [[ "$1" == - || -z $1 ]]; then
-		declare t=$(nexttmp)
+		declare t
+		t=$(nexttmp)
 		head -c 40000 > "$t" 2>/dev/null
 		set "$t" "$2"
 		fname="$fileext"
 	fi
 	fext=$(fileext "$fname")
 	### get file type from mime type
-	declare ft=$(file -L -s -b --mime "$1" 2> /dev/null)
+	declare ft
+	ft=$(file -L -s -b --mime "$1" 2> /dev/null)
 	[[ $ft == *=* ]] && fchar="${ft##*=}" || fchar=utf-8
 	fcat="${ft%/*}"
 	ft="${ft#*/}"; ft="${ft%;*}"; ft="${ft#x-}"
@@ -49,16 +51,18 @@ filetype () {
 		sun.xml.writer)
 			ftype=ooffice1 ;;
 		shellscript)
-			ftype=sh ;;
+			ftype='sh' ;;
 		makefile)
-			ftype=make ;;
+			ftype='make' ;;
 		epub+zip)
 			ftype=epub ;;
+		matlab-data)
+			ftype=matlab ;;
 	# file may report wrong type for given file names (ok in file 5.39)
 		troff)
 			case "${fname##*/}" in
 			[Mm]akefile|[Mm]akefile.*|BSDMakefile)
-				ftype=make ;;
+				ftype='make' ;;
 			esac
 	esac
 	# correct for a more specific file type
@@ -79,8 +83,6 @@ filetype () {
 				ftype=matlab ;;
 			*POD\ document*)
 				ftype=pod ;;
-			*perl\ Storable*)
-				ftype=pst ;;
 			*PEM\ certificate\ request)
 				ftype=csr ;;
 			*PEM\ certificate)
@@ -93,6 +95,8 @@ filetype () {
 				ftype=pgp ;;
 			Audio\ file\ with\ ID3\ *)
 				ftype=mp3 ;;
+			'OpenOffice.org 1.x Writer document')
+				ftype=ooffice1 ;;
 			# if still unspecific, determine file type by extension
 			data)
 				### binary only file formats, type not guessed by 'file'
@@ -133,16 +137,16 @@ filetype () {
 				log)
 					ftype=log ;;
 				ebuild|eclass)
-					ftype=sh ;;
+					ftype='sh' ;;
 			esac
 		fi
 	fi
-	echo $ftype:$fchar:$fcat
+	echo "$ftype:$fchar:$fcat"
 }
 
 msg () {
 	[[ -n "$LESSQUIET" ]] && return;
-	echo "==> $@"
+	echo "==> $*"
 }
 
 contentline () {
@@ -181,14 +185,14 @@ show () {
 		isfinal "$1"
 		return
 	fi
-	file1="${1%%$sep*}"
+	file1="${1%%"$sep"*}"
 	rest1="${1#"$file1"}"
-	while [[ "$rest1" == $sep$sep* ]]; do
-		if [[ "$rest1" == $sep$sep ]]; then
+	while [[ "$rest1" == "$sep$sep"* ]]; do
+		if [[ "$rest1" == "$sep$sep" ]]; then
 			break
 		else
-			rest1="${rest1#$sep$sep}"
-			file1="${rest1%%$sep*}"
+			rest1="${rest1#"$sep$sep"}"
+			file1="${rest1%%"$sep"*}"
 			rest1="${rest1#"$file1"}"
 			file1="${1%"$rest1"}"
 		fi
@@ -196,15 +200,15 @@ show () {
 	if [[ ! -e "$file1" && "$file1" != '-' ]]; then
 		exit 1
 	fi
-	rest11="${rest1#$sep}"
-	file2="${rest11%%$sep*}"
+	rest11="${rest1#"$sep"}"
+	file2="${rest11%%"$sep"*}"
 	rest2="${rest11#"$file2"}"
-	while [[ "$rest2" == $sep$sep* ]]; do
-		if [[ "$rest2" == $sep$sep ]]; then
+	while [[ "$rest2" == "$sep$sep"* ]]; do
+		if [[ "$rest2" == "$sep$sep" ]]; then
 			break
 		else
-			rest2="${rest2#$sep$sep}"
-			file2="${rest2%%$sep*}"
+			rest2="${rest2#"$sep$sep"}"
+			file2="${rest2%%"$sep"*}"
 			rest2="${rest2#"$file2"}"
 			file2="${rest11%"$rest2"}"
 		fi
@@ -212,21 +216,21 @@ show () {
 	rest2="${rest11#"$file2"}"
 	rest11="$rest1"
 
-	if [[ "$cmd" == "" ]]; then
+	if [[ "${cmd[*]}" == "" ]]; then
 		ft=$(filetype "$file1")
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			show "-$rest1"
 		else
 			# if nothing to convert, exit without a command
-			[[ $colorizer == cat ]] && colorizer=
+			[[ ${colorizer[*]} == cat ]] && colorizer=()
 			isfinal "$file1" "$rest11"
 		fi
 	elif [[ "$c1" == "" ]]; then
 		c1=("${cmd[@]}")
 		ft=$("${c1[@]}" | filetype -) || exit 1
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			show "-$rest1"
 		else
 			"${c1[@]}" | isfinal - "$rest11"
@@ -234,8 +238,8 @@ show () {
 	elif [[ "$c2" == "" ]]; then
 		c2=("${cmd[@]}")
 		ft=$("${c1[@]}" | "${c2[@]}" | filetype -) || exit 1
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			show "-$rest1"
 		else
 			"${c1[@]}" | "${c2[@]}" | isfinal - "$rest11"
@@ -243,8 +247,8 @@ show () {
 	elif [[ "$c3" == "" ]]; then
 		c3=("${cmd[@]}")
 		ft=$("${c1[@]}" | "${c2[@]}" | "${c3[@]}" | filetype -) || exit 1
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			show "-$rest1"
 		else
 			"${c1[@]}" | "${c2[@]}" | "${c3[@]}" | isfinal - "$rest11"
@@ -252,8 +256,8 @@ show () {
 	elif [[ "$c4" == "" ]]; then
 		c4=("${cmd[@]}")
 		ft=$("${c1[@]}" | "${c2[@]}" | "${c3[@]}" | "${c4[@]}" | filetype -) || exit 1
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			show "-$rest1"
 		else
 			"${c1[@]}" | "${c2[@]}" | "${c3[@]}" | "${c4[@]}" | isfinal - "$rest11"
@@ -261,8 +265,8 @@ show () {
 	elif [[ "$c5" == "" ]]; then
 		c5=("${cmd[@]}")
 		ft=$("${c1[@]}" | "${c2[@]}" | "${c3[@]}" | "${c4[@]}" | "${c5[@]}" | filetype -) || exit 1
-		get_unpack_cmd $ft "$file1" "$rest1"
-		if [[ "$cmd" != "" && -z $colorizer ]]; then
+		get_unpack_cmd "$ft" "$file1" "$rest1"
+		if [[ "${cmd[*]}" != "" && -z ${colorizer[*]} ]]; then
 			echo "$0: Too many levels of encapsulation"
 		else
 			"${c1[@]}" | "${c2[@]}" | "${c3[@]}" | "${c4[@]}" | "${c5[@]}" | isfinal - "$rest11"
@@ -274,7 +278,7 @@ get_unpack_cmd () {
 	fchar="${1%:*}"; fchar="${fchar#*:}"
 	fcat="${1##*:}"
 	x="${1%%:*}"
-	cmd=
+	cmd=()
 	if [[ "$3" == $sep$sep ]]; then
 		return
 	fi
@@ -286,7 +290,7 @@ get_unpack_cmd () {
 			[[ $2 == - ]] || fileext="$2"
 			fileext=${fileext%%.gz}; fileext=${fileext%%.bz2}
 			[[ $x == compress ]] && x=gzip
-			has_cmd $x && cmd=($x -cd "$2") && return ;;
+			has_cmd "$x" && cmd=("$x" -cd "$2") && return ;;
 		zstd)
 			has_cmd zstd && cmd=(zstd -cdqM1073741824 "$2") && return ;;
 		lz4)
@@ -300,21 +304,21 @@ get_unpack_cmd () {
 	esac
 	# convert into utf8
 
-	if [[ -n $lclocale && $fchar != binary && $fchar != *ascii && $fchar != $lclocale && $fchar != unknown* ]]; then
+	if [[ -n $lclocale && $fchar != binary && $fchar != *ascii && $fchar != "$lclocale" && $fchar != unknown* ]]; then
 		qm="\033[7m?\033[m" # inverted question mark
-		rep=-c
-		trans=
-		echo ""|iconv --byte-subst - 2>/dev/null && rep="--unicode-subst=$qm --byte-subst=$qm --widechar-subst=$qm" # MacOS
-		echo ""|iconv -f $fchar -t $locale//TRANSLIT - 2>/dev/null && trans="-t $locale//TRANSLIT"
+		rep=(-c)
+		trans=()
+		echo ""|iconv --byte-subst - 2>/dev/null && rep=(--unicode-subst="$qm" --byte-subst="$qm" --widechar-subst="$qm") # MacOS
+		echo ""|iconv -f "$fchar" -t "$locale//TRANSLIT" - 2>/dev/null && trans=(-t "$locale//TRANSLIT")
 		msg "append $sep$sep to filename to view the $fchar encoded file"
-		cmd=(iconv $rep -f $fchar $trans "$2")
+		cmd=(iconv "${rep[@]}" -f "$fchar" "${trans[@]}" "$2")
 		# loop protection, just in case
 		lclocale=
 		return
 	fi
-	[[ "$3" == $sep ]] && return
-	file2=${3#$sep}
-	file2=${file2%%$sep*}
+	[[ "$3" == "$sep" ]] && return
+	file2=${3#"$sep"}
+	file2=${file2%%"$sep"*}
 	# remember name of file to extract or file type
 	[[ -n "$file2" ]] && fileext="$file2"
 	# extract from archive
@@ -348,20 +352,20 @@ get_unpack_cmd () {
 			{ has_cmd bsdtar && prog=bsdtar; } ||
 			{ has_cmd isoinfo && prog=isoinfo; } ;;
 		archive)
-			prog=ar
+			prog='ar'
 			has_cmd bsdtar && prog=bsdtar
 	esac
-	[[ -n $prog ]] && cmd=(isarchive $prog "$2" "$file2")
-	if [[ -n $cmd ]]; then
+	[[ -n $prog ]] && cmd=(isarchive "$prog" "$2" "$file2")
+	if [[ -n ${cmd[*]} ]]; then
 		[[ -n "$file2" ]] && file2= && return
 		msg "use ${x}_file${sep}contained_file to view a file in the archive"
-		has_cmd archive_color && colorizer=archive_color || colorizer=cat
+		has_cmd archive_color && colorizer=(archive_color) || colorizer=(cat)
 	fi
 }
 
 analyze_args () {
 	# determine how we are called
-	cmdtree=`ps -T -oargs=`
+	cmdtree=$(ps -T -oargs=)
 	while read -r line; do
 		arg1=${line%% *}; arg1=${arg1##*/}
 		case $arg1 in
@@ -376,7 +380,8 @@ analyze_args () {
 	[[ $lessarg == *less\ *\ +F\ * || $lessarg == *less\ *\ : ]] && exit 0
 	# color is set when calling less with -r or -R or LESS contains that option
 	lessarg="l $LESS $lessarg"
-	lessarg=`echo $lessarg|sed 's/ -[a-zA-Z]*[rR]/ -r/'`
+	# shellcheck disable=SC2001
+	lessarg=$(echo "$lessarg" | sed 's/ -[a-zA-Z]*[rR]/ -r/')
 	has_cmd tput && colors=$(tput colors) || colors=0
 	if [[ $colors -ge 8 && $lessarg == *\ -[rR]* ]]; then
 		COLOR="--color=always"
@@ -395,31 +400,29 @@ has_colorizer () {
 	prog=${LESSCOLORIZER%% *}
 
 	for i in bat batcat pygmentize source-highlight code2color vimcolor ; do
-		[[ -z $prog || $prog == $i ]] && has_cmd $i && prog=$i
+		[[ -z $prog || $prog == "$i" ]] && has_cmd "$i" && prog=$i
 	done
-	[[ "$2" =~ ^[0-9]*$ ]] && opt= || opt=" -l $2"
-	ext=${fileext##*.}
+	[[ "$2" =~ ^[0-9]*$ || -z "$2" ]] && opt=() || opt=(-l "$2")
 	case $prog in
 		bat|batcat)
 			# only allow an explicitly requested language
-			opt=" -l $ext"
-			{ [[ -n $ext ]] && $prog $opt /dev/null; } || opt=
-			opt="$opt $COLOR" ;;
+			[[ -z $3 ]] && opt=() || opt=(-l "$3")
+			opt+=("$COLOR" --style=plain --paging=never) ;;
 		pygmentize)
-				[[ -n $LESSCOLORIZER && $LESSCOLORIZER =~ pygmentize\ \ *-O\ *style=[a-z]* ]] && prog=$LESSCOLORIZER
-				[[ $colors -ge 256 ]] && prog="$prog -f terminal256"
-				res=$(pygmentize -l $2 /dev/null 2>/dev/null) && opt=" -l $2" || opt=" -g" ;;
+			pygmentize -l "$2" /dev/null &>/dev/null && opt=(-l "$2") || opt=(-g)
+			[[ -n $LESSCOLORIZER && $LESSCOLORIZER =~ pygmentize\ \ *-O\ *style=[a-z]* ]] && opt+=(-O "${LESSCOLORIZER##* }")
+			[[ $colors -ge 256 ]] && opt+=(-f terminal256) ;;
 		source-highlight)
-			prog="source-highlight --failsafe -f esc"
 			[[ -z $arg ]] && arg=/dev/stdin
-			[[ -n "$opt" && -n "$2" ]] && opt=" -s $2 -i" || opt=" -i" ;;
+			[[ -n "${opt[*]}" && -n "$2" ]] && opt=(-s "$2") || opt=()
+			opt+=(--failsafe -f esc -i) ;;
 		code2color|vimcolor)
-			opt=
-			[[ -n "$fileext" ]] && opt=" -l $fileext" ;;
+			opt=()
+			[[ -n "$fileext" ]] && opt=(-l "$fileext") ;;
 		*)
 			return ;;
 	esac
-	echo "$prog$opt"
+	colorizer=("$prog" "${opt[@]}")
 }
 
 isfinal () {
@@ -427,19 +430,19 @@ isfinal () {
 		cat "$1"
 		return
 	fi
-	if [[ -z "$cmd" ]]; then
+	if [[ -z "${cmd[*]}" ]]; then
 	# respect extension set by user
 	[[ -n "$file2" && "$fileext" == "$file2" && "$fileext" != *.* ]] && x="$fileext"
 	case "$x" in
 		directory)
-			cmd=(ls -lA $COLOR "$1")
-			if ! ls $COLOR > /dev/null 2>&1; then
+			cmd=(ls -lA "$COLOR" "$1")
+			if ! ls "$COLOR" > /dev/null 2>&1; then
 				cmd=(CLICOLOR_FORCE=1 ls -lA -G "$1")
 				if ! ls -lA -G > /dev/null 2>&1; then
 					cmd=(ls -lA "$1")
 				fi
 			fi
-			msg="$x: showing the output of ${cmd[@]}" ;;
+			msg="$x: showing the output of ${cmd[*]}" ;;
 		html|xml)
 			[[ -z $file2 ]] && has_htmlprog && cmd=(ishtml "$1") ;;
 		pdf)
@@ -450,10 +453,10 @@ isfinal () {
 			has_cmd ps2ascii && nodash ps2ascii "$1" ;;
 		java-applet)
 			# filename needs to end in .class
-			has_cmd procyon && t=$t.class && cat "$1" > $t && cmd=(procyon "$t") ;;
+			has_cmd procyon && t=$t.class && cat "$1" > "$t" && cmd=(procyon "$t") ;;
 		markdown)
-			[[ $COLOR = *always ]] && mdopt= || mdopt=-c
-			{ has_cmd mdcat && cmd=(mdcat $mdopt "$1"); } ||
+			[[ $COLOR = *always ]] && mdopt=() || mdopt=(-c)
+			{ has_cmd mdcat && cmd=(mdcat "${mdopt[@]}" "$1"); } ||
 			{ has_cmd pandoc && cmd=(pandoc -t plain "$1"); } ;;
 		docx)
 			{ has_cmd pandoc && cmd=(pandoc -f docx -t plain "$1"); } ||
@@ -476,7 +479,7 @@ isfinal () {
 		odp)
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" odp); } ;;
 		ods)
-			{ has_cmd xlscat && t=$t.ods && cat "$1" > $t && cmd=(xlscat "$t"); } ||
+			{ has_cmd xlscat && t=$t.ods && cat "$1" > "$t" && cmd=(xlscat "$t"); } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" ods); } ;;
 		msword)
 			t="$1"; [[ "$t" == - ]] && t=/dev/stdin
@@ -493,14 +496,14 @@ isfinal () {
 			{ has_cmd sxw2txt && cmd=(istemp sxw2txt "$1"); } ||
 			{ has_cmd libreoffice && has_htmlprog && cmd=(isoffice "$1" odt); } ;;
 		ipynb|epub)
-			has_cmd pandoc && cmd=(pandoc -f $x -t plain "$1") ;;
+			has_cmd pandoc && cmd=(pandoc -f "$x" -t plain "$1") ;;
 		troff)
 			if has_cmd groff; then
 				fext=$(fileext "$1")
 				declare macro=andoc
-				[[ fext == me ]] && macro=e
-				[[ fext == ms ]] && macro=s
-				cmd=(groff -s -p -t -e -Tutf8 -m$macro "$1")
+				[[ "$fext" == me ]] && macro=e
+				[[ "$fext" == ms ]] && macro=s
+				cmd=(groff -s -p -t -e -Tutf8 -m "$macro" "$1")
 			fi ;;
 		rtf)
 			{ has_cmd unrtf && cmd=(istemp "unrtf --text" "$1"); } ||
@@ -513,9 +516,7 @@ isfinal () {
 			[[ -z $file2 ]] && LESSQUIET=1 &&
 			{ { has_cmd pod2text && cmd=(pod2text "$1"); } ||
 			{ has_cmd perldoc && cmd=(istemp perldoc "$1"); }; } ;;
-		pst)
-			has_cmd perl && cmd=(perl -MStorable=retrieve -MData::Dumper -e '$Data::Dumper::Indent=1;print Dumper retrieve shift' "$1") ;;
-		hdf)
+		hdf|hdf5)
 			{ has_cmd h5dump && cmd=(istemp h5dump "$1"); } ||
 			{ has_cmd ncdump && cmd=(istemp ncdump "$1"); } ;;
 		matlab)
@@ -533,7 +534,7 @@ isfinal () {
 		mp3)
 			has_cmd id3v2 && cmd=(istemp "id3v2 --list" "$1") ;;
 		log)
-			has_cmd ccze && [[ $COLOR = *always ]] && cat "$1" | ccze -A
+			has_cmd ccze && [[ $COLOR = *always ]] && ccze -A < "$1"
 			return ;;
 		csv)
 			{ has_cmd csvlook && cmd=(csvlook "$1"); } ||
@@ -541,22 +542,22 @@ isfinal () {
 	esac
 	fi
 	# not a specific file format
-	if [[ -z "$cmd" ]]; then
+	if [[ -z ${cmd[*]} ]]; then
 		fext=$(fileext "$1")
 		if [[ $fcat == audio || $fcat == video || $fcat == image ]]; then
 			{ has_cmd mediainfo && cmd=(mediainfo --Full "$1"); } ||
 			{ has_cmd exiftool && cmd=(exiftool "$1"); } ||
-			{ has_cmd identify && $fcat == image && cmd=(identify -verbose "$1"); }
+			{ has_cmd identify && [[ $fcat == image ]] && cmd=(identify -verbose "$1"); }
 		elif [[ "$fchar" == binary ]]; then
 			cmd=(nodash strings "$1")
 		fi
 	fi
-	if [[ -n $cmd && $cmd != "cat" ]]; then
+	if [[ -n ${cmd[*]} && "${cmd[*]}" != "cat" ]]; then
 		[[ -z $msg ]] && msg="append $sep to filename to view the $x file"
-		msg $msg
+		msg "$msg"
 	fi
-	if [[ -n $cmd ]]; then
-		if [[ $colorizer == archive_color && $COLOR == *always ]]; then
+	if [[ -n ${cmd[*]} ]]; then
+		if [[ ${colorizer[*]} == archive_color && $COLOR == *always ]]; then
 			"${cmd[@]}" | archive_color
 		else
 			"${cmd[@]}"
@@ -566,20 +567,20 @@ isfinal () {
 		[[ -z "$fext" && $fcat == text && $x != plain ]] && fext=$x
 		[[ -z "$fext" ]] && fext=$(fileext "$fileext")
 		fext=${fext##*/}
-		[[ -z $colorizer ]] && colorizer=$(has_colorizer "$1" "$fext")
-		[[ -n $colorizer && $fcat != binary ]] && $colorizer "$1" && return
+		[[ -z ${colorizer[*]} ]] && has_colorizer "$1" "$fext" "$file2"
+		[[ -n ${colorizer[*]} && $fcat != binary ]] && "${colorizer[@]}" "$1" && return
 		# if fileext set, we need to filter to get rid of .fileext
-		[[ -n $fileext || "$1" == - || "$1" == $t ]] && cat "$1"
+		[[ -n $fileext || "$1" == - || "$1" == "$t" ]] && cat "$1"
 	fi
 }
 
 isarchive () {
 	prog=$1
-	[[ "$2" =~ ^[a-z_-]*:.* ]] && echo $2: remote operation tar host:file not allowed && return
+	[[ "$2" =~ ^[a-z_-]*:.* ]] && echo "$2: remote operation tar host:file not allowed" && return
 	if [[ -n $3 ]]; then
 		case $prog in
 			tar|bsdtar)
-				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo $2: remote operation tar host:file not allowed && return
+				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo "$2: remote operation tar host:file not allowed" && return
 				$prog Oxf "$2" "$3" 2>/dev/null;;
 			rar|unrar)
 				istemp "$prog p -inul" "$2" "$3" ;;
@@ -597,7 +598,7 @@ isarchive () {
 	else
 		case $prog in
 			tar|bsdtar)
-				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo $2: remote operation tar host:file not allowed && return
+				[[ "$2" =~ ^[a-z_-]*:.* ]] && echo "$2: remote operation tar host:file not allowed" && return
 				$prog tvf "$2" ;;
 			rar|unrar)
 				istemp "$prog v" "$2" ;;
@@ -617,6 +618,7 @@ isarchive () {
 				istemp "$prog l" "$2"
 		esac
 	fi
+	[[ $? && $3 ]] && msg "could not retrieve $3 from $2"
 }
 
 cabextract2 () {
@@ -656,7 +658,7 @@ isdeb () {
 		data=$(bsdtar tf "$1" "data*")
 		if [[ -z "$2" ]]; then
 			control=$(bsdtar tf "$1" "control*")
-			bsdtar xOf "$1" $control | bsdtar xOf - ./control
+			bsdtar xOf "$1" "$control" | bsdtar xOf - ./control
 			contentline
 			bsdtar xOf "$1" "$data" | bsdtar tvf -
 		else
@@ -665,14 +667,14 @@ isdeb () {
 	else
 		data=$(ar t "$1"|grep data)
 		ft=$(ar p "$1" "$data" | filetype -)
-		get_unpack_cmd $ft -
+		get_unpack_cmd "$ft" -
 		if [[ -z "$2" ]]; then
 			control=$(ar t "$1"|grep control)
-			ar p "$1" $control | ${cmd[@]} | tar xOf - ./control
+			ar p "$1" "$control" | "${cmd[@]}" | tar xOf - ./control
 			contentline
-			ar p "$1" "$data" | ${cmd[@]} | tar tvf -
+			ar p "$1" "$data" | "${cmd[@]}" | tar tvf -
 		else
-			ar p "$1" "$data" | ${cmd[@]} | tar xOf - "$2"
+			ar p "$1" "$data" | "${cmd[@]}" | tar xOf - "$2"
 		fi
 	fi
 }
@@ -680,9 +682,9 @@ isdeb () {
 isoffice () {
 	t=$(nexttmp)
 	t2=$t."$2"
-	cat "$1" > $t2
+	cat "$1" > "$t2"
 	libreoffice --headless --convert-to html --outdir "$tmpdir" "$t2" > /dev/null 2>&1
-	ishtml $t.html
+	ishtml "$t.html"
 }
 
 isoffice2 () {
@@ -699,7 +701,7 @@ has_htmlprog () {
 handle_w3m () {
 	if [[ "$1" == *\?* ]]; then
 		t=$(nexttmp)
-		ln -s "$1" $t
+		ln -s "$1" "$t"
 		set "$t" "$1"
 	fi
 	nodash "w3m -dump -T text/html" "$1"
@@ -723,30 +725,30 @@ setopt sh_word_split 2>/dev/null
 PATH=$PATH:${0%%/lesspipe.sh}
 # the current locale in lowercase (or generic utf-8)
 locale=$(locale|grep LC_CTYPE|sed 's/.*"\(.*\)"/\1/') || locale=en_US.UTF-8
-lclocale=$(echo ${locale##*.}|tr '[A-Z]' '[a-z]')
+lclocale=$(echo ${locale##*.}|tr '[:upper:]' '[:lower:]')
 
 sep=:					# file name separator
-altsep==				# alternate separator character
-if [[ -e "$1" && "$1" == *$sep* ]]; then
+altsep='='				# alternate separator character
+if [[ -e "$1" && "$1" == *"$sep"* ]]; then
 	sep=$altsep
-elif [[ "$1" == *$altsep* ]]; then
-	[[ -e "${1%%$altsep*}" ]] && sep=$altsep
+elif [[ "$1" == *"$altsep"* ]]; then
+	[[ -e "${1%%"$altsep"*}" ]] && sep=$altsep
 fi
 
 tmpdir=${TMPDIR:-/tmp}/lesspipe."$RANDOM"
 [[ -d "$tmpdir" ]] || mkdir "$tmpdir"
 [[ -d "$tmpdir" ]] || exit 1
-trap "rm -rf '$tmpdir';exit 1" INT
-trap "rm -rf '$tmpdir'" EXIT
+trap 'rm -rf "$tmpdir";exit 1' INT
+trap 'rm -rf "$tmpdir"' EXIT
 trap - PIPE
 
 t=$(nexttmp)
 analyze_args
 # make LESSOPEN="|- ... " work
 if [[ $LESSOPEN == *\|-* && $1 == - ]]; then
-	cat > $t
+	cat > "$t"
 	[[ -n "$fext" ]] && t="$t$sep$fext"
-	set $1 "$t"
+	set "$1" "$t"
 	nexttmp >/dev/null
 fi
 
@@ -766,3 +768,4 @@ else
 	fi
 	show "$@"
 fi
+
